==> rktSNS_1.070120.tgz: rktSNS/webapp/modules/private/home/search.php <==
<?php
/* ========================================================================
 - [modules/private/home/search.php]
 -      各種検索
 -      Copyright (c) 2006 Yujiro Takahashi
 - ライセンス:
 -      This program is free software; you can redistribute it and/or
 -      modify it under the terms of the GNU General Public License
 -      as published by the Free Software Foundation; either version 2
 -      of the License, or (at your option) any later version.
 -
 -      This program is distributed in the hope that it will be useful,
 -      but WITHOUT ANY WARRANTY; without even the implied warranty of
 -      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 -      GNU General Public License for more details.
 -
 -      You should have received a copy of the GNU General Public License
 -      along with this program; if not, write to the Free Software
 -      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 - 問い合わせ先：
 -      yujiro@rakuto.net
 -      http://rakuto.net/rktSNS/
 - 更新履歴：
 -      [2006/07/10] 作成
 - ======================================================================== */

/* =-=- モジュール等の読み込み -=-= */
require_once WEBAPP_LIB_DIR.'wap_private.php';

/**
 * WebApplication実装クラス
 *
 * @author 高橋 裕志郎 <yujiro@rakuto.net>
 * @package webapp
 * @access public
 * @version 1.0
 */
class webapp extends WAP_private
{
    /**
     * データ操作オブジェクト
     * @var object
     */
    var $objmnp = null;

    /**
     * 実行処理
     *
     * @access public
     * @return void
     **/
    function execute()
    {
        RKT_auth::Authenticate(array(WAP_ACC_ADMIN,WAP_ACC_MEMBER));

        $this->setTemplateFile('private/home/home.tpl');
        
        $keyword = empty($_GET['keyword'])?'':urlencode($_GET['keyword']);
        
        if (isset($_GET['diary'])){
            header('Location: '.HTTP_ACTION.'friend/diary/result/'.WAP_URI_SEPARATOR.'keyword='.$keyword);
        } elseif (isset($_GET['forum'])){
            header('Location: '.HTTP_ACTION.'friend/forum/result/'.WAP_URI_SEPARATOR.'keyword='.$keyword);
        } else {
            header('Location: '.HTTP_ACTION.'private/review/search/'.WAP_URI_SEPARATOR.'keyword='.$keyword);
        }

        exit();
    }
} // webapp
?>

==> rktSNS_1.070428.tgz: rktSNS/webapp/modules/private/home/search.php <==
<?php
/* ========================================================================
 - [modules/private/home/search.php]
 -      各種検索
 -      Copyright (c) 2006 Yujiro Takahashi
 - ライセンス:
 -      This program is free software; you can redistribute it and/or
 -      modify it under the terms of the GNU General Public License
 -      as published by the Free Software Foundation; either version 2
 -      of the License, or (at your option) any later version.
 -
 -      This program is distributed in the hope that it will be useful,
 -      but WITHOUT ANY WARRANTY; without even the implied warranty of
 -      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 -      GNU General Public License for more details.
 -
 -      You should have received a copy of the GNU General Public License
 -      along with this program; if not, write to the Free Software
 -      Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 - 問い合わせ先：
 -      yujiro@rakuto.net
 -      http://rakuto.net/rktSNS/
 - 更新履歴：
 -      [2006/07/10] 作成
 - ======================================================================== */

/* =-=- モジュール等の読み込み -=-= */
require_once WEBAPP_LIB_DIR.'wap_private.php';

/**
 * WebApplication実装クラス
 *
 * @author 高橋 裕志郎 <yujiro@rakuto.net>
 * @package webapp
 * @access public
 * @version 1.0
 */
class webapp extends WAP_private
{
    /**
     * データ操作オブジェクト
     * @var object
     */
    var $objmnp = null;

    /**
     * 実行処理
     *
     * @access public
     * @return void
     **/
    function execute()
    {
        RKT_auth::Authenticate(array(WAP_ACC_ADMIN,WAP_ACC_MEMBER));

        $this->setTemplateFile('private/home/home.tpl');
        
        $keyword = empty($_REQUEST['keyword'])?'':urlencode($_REQUEST['keyword']);
        
        if (isset($_REQUEST['diary'])){
            header('Location: '.HTTP_ACTION.'friend/diary/result/'.WAP_URI_SEPARATOR.'keyword='.$keyword);
        } elseif (isset($_REQUEST['forum'])){
            header('Location: '.HTTP_ACTION.'friend/forum/result/'.WAP_URI_SEPARATOR.'keyword='.$keyword);
        } else {
            header('Location: '.HTTP_ACTION.'private/review/search/'.WAP_URI_SEPARATOR.'keyword='.$keyword);
        }

        exit();
    }
} // webapp
?>
